@@ -13,6 +13,8 @@ class FieldType(Enum):
     STRING = "string"
     BOOLEAN = "boolean"
     DATETIME = "datetime"
+    VECTOR = "vector"
+    TEXT = "text"
 
 
 class FieldCategory(Enum):
@@ -28,10 +30,10 @@ class FieldCategory(Enum):
         """Builds a field cateogry from a camelCase string.
 
         Args:
-            value (str): Category value
+            value: Category value
 
         Returns:
-            FieldCategory: Category that matches the given value
+            Category that matches the given value
         """
         if value == "rawInputs":
             return FieldCategory.RAW_INPUTS
