@@ -13,6 +13,7 @@ from aporia.core.logging_utils import LOGGER_NAME
 from aporia.core.types.field import FieldValue
 from aporia.inference.api.log_model_properties import (
     log_index_to_word_mapping,
+    set_feature_importance,
     upload_model_artifact,
 )
 from .api.inference_fragment import ActualsFragment, Fragment, PredictionFragment, RawInputsFragment
@@ -294,6 +295,23 @@ class InferenceModel(BaseModel):
                 )
             )
 
+    @validate_model_ready
+    def set_feature_importance(self, feature_importance: Dict[str, float]):
+        """Update the features' importance of the model.
+
+        Args:
+            feature_importance: feature name to importance mapping
+        """
+        with self.handle_error("Setting feature importance failed, error: {}", throw_errors=False):
+            self._event_loop.run_coroutine(
+                set_feature_importance(
+                    http_client=self._http_client,
+                    model_id=self.model_id,
+                    model_version=self.model_version,
+                    feature_importance=feature_importance,
+                )
+            )
+
     @validate_model_ready
     def log_index_to_word_mapping(self, index_to_word_mapping: Dict[Any, Any]):
         """Logs index to word mapping.
