@@ -1,4 +1,4 @@
-from typing import Any, Optional
+from typing import Any, Optional, Union
 
 from aporia.core.errors import AporiaError
 from aporia.inference.inference_model import InferenceModel
@@ -81,9 +81,12 @@ class Model(InferenceModel):
         )
 
     def log_training_set(
-        self, features: DataFrame, labels: DataFrame, raw_inputs: Optional[DataFrame] = None  # type: ignore
+        self,
+        features: Union[DataFrame, ndarray],  # type: ignore
+        labels: DataFrame,  # type: ignore
+        raw_inputs: Optional[DataFrame] = None,  # type: ignore
     ):
-        """Logs training data.
+        """Logs aggregations of the whole set and logs a sample of the data.
 
         Args:
             features: Training set features
@@ -113,9 +116,38 @@ class Model(InferenceModel):
 
             self._training.log_training_set(features=features, labels=labels, raw_inputs=raw_inputs)
 
+    def log_training_sample(self, features: Union[DataFrame, ndarray], labels: DataFrame):  # type: ignore
+        """Logs a sample of the training data.
+
+        Args:
+            features: Training set features
+            labels: Training set labels
+
+        Notes:
+            * Each dataframe corresponds to a field category defined in create_model_version:
+                * features -> features
+                * labels -> predictions
+            * Each column in the dataframe should match a field defined in create_model_version
+                * Missing fields will be handled as missing values
+                * Columns that do not match a defined field will be ignored
+                * The column name must match the field name
+            * This function is blocking and may take a while to finish running.
+        """
+        with self.handle_error("{}"):
+            if self._training is None:
+                raise AporiaError(
+                    short_message="Logging training samples failed, Aporia training extension not found",
+                    verbose_message=(
+                        "The Aporia training extension is required to log training samples. "
+                        "Install it with `pip install aporia[training] and try again."
+                    ),
+                )
+
+            self._training.log_training_sample(features=features, labels=labels)
+
     def log_test_set(
         self,
-        features: DataFrame,  # type: ignore
+        features: Union[DataFrame, ndarray],  # type: ignore
         predictions: DataFrame,  # type: ignore
         labels: DataFrame,  # type: ignore
         raw_inputs: Optional[DataFrame] = None,  # type: ignore
