@@ -207,7 +207,7 @@ async def log_test_data(
         logger.warning(warning)
 
 
-async def log_training_sample(
+async def log_training_sample_data(
     http_client: HttpClient,
     model_id: str,
     model_version: str,
