@@ -1,8 +1,8 @@
 from functools import lru_cache
 import logging
-from typing import Dict, List, Optional, Tuple, Union
+from typing import cast, Dict, List, Optional, Tuple, Union
 
-from numpy import ndarray
+from numpy import nan, ndarray
 from pandas import DataFrame
 
 from aporia.core.base_model import BaseModel, validate_model_ready
@@ -14,7 +14,7 @@ from .api.log_training import (
     FieldTrainingData,
     log_test_data,
     log_training_data,
-    log_training_sample,
+    log_training_sample_data,
 )
 from .training import calculate_dataframe_training_data
 from .training_validator import TrainingDataset, TrainingValidator
@@ -191,11 +191,14 @@ class TrainingModel(BaseModel):
         if isinstance(features, ndarray):
             features, _ = self._build_features_dataframe_and_schema(features)
 
-        features_sample = features.sample(min(SAMPLE_SIZE, len(features)))
-        labels_sample = labels.sample(min(SAMPLE_SIZE, len(labels)))
+        # Null values are replaced with np.nan, because orjson can't serialize pd.NA
+        features_sample = cast(
+            DataFrame, features.sample(min(SAMPLE_SIZE, len(features))).fillna(nan)
+        )
+        labels_sample = cast(DataFrame, labels.sample(min(SAMPLE_SIZE, len(labels))).fillna(nan))
 
         self._event_loop.run_coroutine(
-            log_training_sample(
+            log_training_sample_data(
                 http_client=self._http_client,
                 model_id=self.model_id,
                 model_version=self.model_version,
